/*
 * Example1_5.java	showcases some Java 1.5 features.
 */
import java.util.ArrayList;
import java.util.Scanner;
import java.io.File;

public class Example1_5 {

  // enumerated types are better than lots of "public static final"
  // variables.
  public enum DayOfWeek { sun, mon, tue, wed, thr, fri, sat };

	// generic types are important.
	ArrayList<Integer> numbers;

  public Example1_5()
  {
    // note that the constructor should match the type.
    numbers = new ArrayList<Integer>();
  }

  public void read( String filename ) throws Exception
  {
    // reading from a text file (and from console) is much easier.
    Scanner in = new Scanner( new File(filename) );
    while( in.hasNext() )
      numbers.add( in.nextInt() ); // auto-boxing
    in.close();
  }

  public void average()
  {
    double avg = 0;
    
    for( int i=0 ; i < numbers.size() ; ++i )
      avg += numbers.get(i); // auto-unboxing

    // formatted output is eaiser, and %n is more portable than \n.
    System.out.printf( "average is %.2f%n" , avg/numbers.size() );
  }

  public void print()
  {
    // new syntax for for-loop so we don't have to use Iterator
    // explicitly. 
    for( Integer i : numbers ) System.out.print( i + " " );
    System.out.println();
  }

  // create a method which takes any number of parameters (which
  // have to be of the same type though)
  public void print( String ... args )
  {
    if( args.length == 0 ) System.out.println( "no parameter specified." );

    // the arguments can be access as array elements
    // for( int i=0 ; i < args.length ; ++i ) System.out.print( args[i] + " " );
    // or as elements of a collection
    for( String s : args ) System.out.print( s + " " );
    System.out.println();
  }

  public static void main( String args[] ) throws Exception
  {
    Example1_5 e = new Example1_5();
    e.read( "test.txt" );
    e.print();
    e.average();
    e.print( "test1", "test2" );
    e.print( "test3" );
    e.print();

    DayOfWeek day = Example1_5.DayOfWeek.tue;
    // assigning day to anything other than the pre-defined values would
    // cause a compilation error.
    // day = -2;
    System.out.println( day );

    // the new syntax of for-loop work for arrays too.
    int iarray[] = new int[3];
    iarray[0] = 100;
    iarray[1] = 120;
    iarray[2] = 200;
    for( int n : iarray ) System.out.println( n );
  }

} // end of class Example1_5

